@@ -9,36 +9,11 @@ from requests.adapters import HTTPAdapter
 from requests_oauthlib import OAuth2Session
 from urllib3.util.retry import Retry
 
-from commercetools import schemas
+from commercetools._schemas._error import ErrorResponseSchema
 from commercetools.constants import HEADER_CORRELATION_ID
 from commercetools.exceptions import CommercetoolsError
 from commercetools.helpers import _concurrent_retry
-from commercetools.services.api_clients import ApiClientService
-from commercetools.services.cart_discounts import CartDiscountService
-from commercetools.services.carts import CartService
-from commercetools.services.categories import CategoryService
-from commercetools.services.channels import ChannelService
-from commercetools.services.custom_objects import CustomObjectService
-from commercetools.services.customer_groups import CustomerGroupService
-from commercetools.services.customers import CustomerService
-from commercetools.services.discount_codes import DiscountCodeService
-from commercetools.services.extensions import ExtensionService
-from commercetools.services.inventory import InventoryService
-from commercetools.services.orders import OrderService
-from commercetools.services.payments import PaymentService
-from commercetools.services.product_discounts import ProductDiscountService
-from commercetools.services.product_projections import ProductProjectionService
-from commercetools.services.product_types import ProductTypeService
-from commercetools.services.products import ProductService
-from commercetools.services.project import ProjectService
-from commercetools.services.reviews import ReviewService
-from commercetools.services.shipping_methods import ShippingMethodService
-from commercetools.services.shopping_lists import ShoppingListService
-from commercetools.services.states import StateService
-from commercetools.services.stores import StoreService
-from commercetools.services.subscriptions import SubscriptionService
-from commercetools.services.tax_categories import TaxCategoryService
-from commercetools.services.types import TypeService
+from commercetools.services import ServicesMixin
 from commercetools.utils import BaseTokenSaver, DefaultTokenSaver, fix_token_url
 
 
@@ -49,7 +24,7 @@ class RefreshingOAuth2Session(OAuth2Session):
         return self.fetch_token(token_url, **kwargs)
 
 
-class Client:
+class Client(ServicesMixin):
     """The Commercetools Client, used to interact with the Commercetools API.
 
     :param project_key: the key for the project with which you want to interact
@@ -64,30 +39,6 @@ class Client:
 
     """
 
-    api_clients: ApiClientService
-    categories: CategoryService
-    custom_objects: CustomObjectService
-    cart_discounts: CartDiscountService
-    carts: CartService
-    channels: ChannelService
-    customer_groups: CustomerGroupService
-    discount_codes: DiscountCodeService
-    extensions: ExtensionService
-    orders: OrderService
-    products: ProductService
-    product_discounts: ProductDiscountService
-    project: ProjectService
-    payments: PaymentService
-    product_projections: ProductProjectionService
-    product_types: ProductTypeService
-    reviews: ReviewService
-    shipping_methods: ShippingMethodService
-    shopping_lists: ShoppingListService
-    stores: StoreService
-    subscriptions: SubscriptionService
-    tax_categories: TaxCategoryService
-    types: TypeService
-
     def __init__(
         self,
         project_key: str = None,
@@ -153,40 +104,16 @@ class Client:
             )
             self._save_token(token)
 
-        self.api_clients = ApiClientService(self)
-        self.categories = CategoryService(self)
-        self.custom_objects = CustomObjectService(self)
-        self.cart_discounts = CartDiscountService(self)
-        self.carts = CartService(self)
-        self.channels = ChannelService(self)
-        self.customer_groups = CustomerGroupService(self)
-        self.customers = CustomerService(self)
-        self.discount_codes = DiscountCodeService(self)
-        self.extensions = ExtensionService(self)
-        self.inventory = InventoryService(self)
-        self.orders = OrderService(self)
-        self.products = ProductService(self)
-        self.product_discounts = ProductDiscountService(self)
-        self.project = ProjectService(self)
-        self.payments = PaymentService(self)
-        self.product_projections = ProductProjectionService(self)
-        self.product_types = ProductTypeService(self)
-        self.reviews = ReviewService(self)
-        self.shipping_methods = ShippingMethodService(self)
-        self.shopping_lists = ShoppingListService(self)
-        self.states = StateService(self)
-        self.stores = StoreService(self)
-        self.subscriptions = SubscriptionService(self)
-        self.tax_categories = TaxCategoryService(self)
-        self.types = TypeService(self)
-
     def _save_token(self, token):
         self._token_saver.add_token(
             self._config["client_id"], self._config["scope"], token
         )
 
     def _get(
-        self, endpoint: str, params: typing.Dict[str, typing.Any], schema_cls: SchemaABC
+        self,
+        endpoint: str,
+        params: typing.Dict[str, typing.Any],
+        schema_cls: typing.Type[SchemaABC],
     ) -> typing.Any:
         """Retrieve a single object from the commercetools platform"""
         response = self._http_client.get(self._base_url + endpoint, params=params)
@@ -200,8 +127,8 @@ class Client:
         endpoint: str,
         params: typing.Dict[str, str],
         data_object: typing.Any,
-        request_schema_cls: SchemaABC,
-        response_schema_cls: SchemaABC,
+        request_schema_cls: typing.Optional[typing.Type[SchemaABC]],
+        response_schema_cls: typing.Type[SchemaABC],
         form_encoded: bool = False,
         force_update: bool = False,
     ) -> typing.Any:
@@ -209,7 +136,7 @@ class Client:
 
         @_concurrent_retry(3 if force_update else 0)
         def remote_http_call(data):
-            if form_encoded:
+            if form_encoded and data is not None:
                 kwargs = {"data": data}
             else:
                 kwargs = {"json": data}
@@ -221,7 +148,10 @@ class Client:
                 return response_schema_cls().load(response.json())
             return self._process_error(response)
 
-        data = request_schema_cls().dump(data_object)
+        if request_schema_cls is not None:
+            data = request_schema_cls().dump(data_object)
+        else:
+            data = None
         return remote_http_call(data)
 
     def _upload(
@@ -229,7 +159,7 @@ class Client:
         endpoint: str,
         params: typing.Dict[str, str],
         file: typing.IO,
-        response_schema_cls: SchemaABC,
+        response_schema_cls: typing.Type[SchemaABC],
     ) -> typing.Any:
         """Retrieve a single object from the commercetools platform"""
         response = self._http_client.post(
@@ -244,7 +174,7 @@ class Client:
         self,
         endpoint: str,
         params: typing.Dict[str, str],
-        response_schema_cls: SchemaABC,
+        response_schema_cls: typing.Type[SchemaABC],
         force_delete: bool = False,
     ) -> typing.Any:
         """Delete an object from the commercetools platform"""
@@ -264,7 +194,7 @@ class Client:
         correlation_id = response.headers.get(HEADER_CORRELATION_ID)
         if not response.content:
             response.raise_for_status()
-        obj = schemas.ErrorResponseSchema().loads(response.content)
+        obj = ErrorResponseSchema().loads(response.content)
 
         # We'll fetch the 'raw' errors from the response because some of the
         # attributes are not included in the schemas.
